<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\InterviewSlot;
use Illuminate\Support\Facades\Mail;
use App\Models\User;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use Auth;

use Illuminate\Validation\Rule;


class InterviewSlotController extends Controller
{

    public function index($status= ""){
          $mytime = Carbon::now();
          $c_date= $mytime->toDateString();
        if($status == "all"):
            $dat = InterviewSlot::where('status' , '!=' , "D")->where('date','>=', $c_date)
            ->orderBy('date', 'DESC')
            ->orderBy('time', 'ASC')
            ->get(); 
            $title = "All Interview Slots";
        elseif($status == "filter"):
            $dat = InterviewSlot::where('status' , '!=' , "D")
            ->orderBy('date', 'DESC')
            ->orderBy('time', 'ASC')
            ->get(); 
            $title = "All Interview Slots";
        elseif($status == 'requested'):
            $dat = InterviewSlot::whereStatus("R")->get();
            $title = "Requested Slots";
        elseif($status == 'rejected'):
            $dat = InterviewSlot::whereStatus("D")->get();
            $title = "Rejected Slots";
        elseif($status == 'accepted'):
            $dat = InterviewSlot::whereStatus("A")->get();
            $title = "Interview Slots";
        elseif($status == 'canceled'):
            $dat = InterviewSlot::whereStatus("C")->get();
            $title = "Cancelled Slots";
        endif;
        $tip = User::where('user_type' , 'tip')->get();
        return view('admin.interview-slots.index' , compact('dat' , 'tip' , 'status' , 'title'));
    }


    public function store(Request $request){
        $rules =
            [
              'date'=>["required",
                  Rule::unique('interview_slots' , 'date')->where(function ($query) use ($request) {
                    return $query->where('date', $request->date)
                    ->where('time', $request->time)
                    ->where('status', 'A');
                })
                ],
              'time' =>[
                  'required',
                  Rule::unique('interview_slots' , 'time')->where(function ($query) use ($request) {
                    return $query->where('date', $request->date)
                    ->where('time', $request->time)
                    ->where('status', 'A');

                })
                ],
              'zoom_link' =>'required',
              'interviewer_primary_id' =>'required|different:interviewer_secondary_id|different:interviewer_tertiary_id',
              'interviewer_secondary_id' =>'required|different:interviewer_primary_id|different:interviewer_tertiary_id',
              'interviewer_tertiary_id' =>'required|different:interviewer_secondary_id|different:interviewer_primary_id',
            ];
            $message = [
               'date.required' => 'Date is required',
               'time.required' =>'Time is required',
               'zoom_link.required' =>'Zoom Link is required',
               'interviewer_primary_id.required' =>'Primary Interviewer is required',
               'interviewer_secondary_id.required' =>'Secondary Interviewer is required',
               'interviewer_tertiary_id.required' =>'Tertiary Interviewer is required',
               'interviewer_primary_id.different:interviewer_secondary_id' => "Primary Interviwer And Secondary interviwere can't be same",
               'interviewer_primary_id.different:interviewer_tertiary_id' => "Primary Interviwer And Tertiary interviwere can't be same",
               'interviewer_secondary_id.different:interviewer_primary_id' => "Secondary Interviwer And Primary interviwere can't be same",
               'interviewer_secondary_id.different:interviewer_tertiary_id' => "Secondary Interviwer And Tertiary interviwere can't be same",
               'interviewer_tertiary_id.different:interviewer_primary_id' => "Tertiary Interviwer And Primary interviwere can't be same",
               'interviewer_tertiary_id.different:interviewer_secondary_id' => "Tertiary Interviwer And Secondary interviwere can't be same",
            ]
        ;
        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->getMessageBag()->toArray()]);
        }

        $input = $request->all();
       
        $slot = new InterviewSlot();
        $input['date'] = $slot->set_date($input['date']);
        $input['status'] ="P";
        $slot->fill($input);
        $slot->save();
        $msg = 'Added Successfully.';
        return response()->json(['msg'=>$msg]);
    }

    public function update(Request $request , $id){
        $rules =
            [
              'date'=>"required",
              'time' =>'required',
              'zoom_link' =>'required',
              'interviewer_primary_id' =>'required',
              'interviewer_secondary_id' =>'required',
              'interviewer_tertiary_id' =>'required',
            ];
            $message = [
               'date.required' => 'Date is required',
               'time.required' =>'Time is required',
               'zoom_link.required' =>'Zoom Link is required',
               'interviewer_primary_id.required' =>'Primary Interviewer is required',
               'interviewer_secondary_id.required' =>'Secondary Interviewer is required',
               'interviewer_tertiary_id.required' =>'Tertiary Interviewer is required',
            ]
        ;

        $validator = Validator::make($request->all(), $rules, $message);

        if ($validator->fails()) {
            return back()->with(['errors' => $validator->getMessageBag()->toArray()]);
        }
        $input = $request->all();
        $input['status'] = "P";
        $slot = InterviewSlot::findOrFail($id);
        if($request->date)
            $input['date'] = $slot->set_date($input['date']);
        $slot->fill($input);
        $slot->update();
        return back()->with("success", "Updated Successfully");
    }


    public function status(Request $request , $id , $status){
        $slot = InterviewSlot::findOrFail($id);
        $slot->status = $status;
        $slot->updated_by = Auth::user()->id;
        if($request->cancel_reason){
            $slot->cancel_reason = $request->cancel_reason;
        }
        $slot->update();
        if($slot->interviewee_id != null){
            $user = User::find($slot->interviewee_id);
            $cname = $user->first_name;
            $to = $user->email;
            if($slot->status == "A"){
                $subject="Interview Slot Accepted";
                $text="Interview Slot has been Accepted";
                $dec="Interview Slot has been Accepted Prepare yourself for interview";
                $link = route('login');
            }else if($slot->status == "D"){
                $subject="Interview Slot Rejected";
                $text="Select another slot";
                $dec="Interview Slot has been Rejected. Select another slot";
                $link = route('volunteer.interview-slots.index' , 'all');
            }else if($slot->status == "C"){
                $subject="Interview Slot Cancelled";
                $text="Select another slot";
                $dec="Interview Slot has been Cancelled. Select another slot";
                $link = route('volunteer.interview-slots.index' , 'all');
            }
    
            Mail::send('email.application', ['cname' => $cname, 'dec'=>$dec ,'text' => $text, 'link' => $link], function ($message) use ($cname , $to , $subject) {
                $message->to($to , $cname);
                $message->subject($subject);
                $message->from(env('MAIL_FROM_ADDRESS') , 'Tip User');
           });
        }

        return back()->with("success", "Updated Successfully");
    }

    public function show(){

    }

    public function destroy($id){
        InterviewSlot::find($id)->delete();
        return back()->with("success", "Deleted Successfully");

    }

}