<?php

namespace App\Models;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use App\Models\Application;

class User extends Authenticatable implements MustVerifyEmail
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var string[]
     */
    protected $fillable = [
        'first_name',
        'last_name',
        'phone',
        'email',
        'address_one',
        'address_two',
        'city',
        'postal_code',
        'uname',
        'password',
        'user_type',
        'status',
        'province',
        'referal_id',
        'updated_by',
    
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function get_name(){
        return $this->first_name . " ". $this->last_name;
    }
    public function application(){
        return $this->hasOne('App\Models\Application' , 'user_id');
    }

    public function short_list(){
        return $this->hasOne('App\Models\Application' , 'user_id')->whereStatus('S');
        
    }
    
    public function volunteer(){
        return $this->hasOne('App\Models\Application' , 'user_id')->whereStatus('A');    
    }
    public function form_one(){
        return $this->hasOne('App\Models\VolunteerFormOne' , 'volunteer_id');
    }
    public function form_two(){
        return $this->hasOne('App\Models\VolunteerFormTwo' , 'volunteer_id');
    }
    public function form_three(){
        return $this->hasOne('App\Models\VolunteerFormThree' , 'volunteer_id');
    }

    public function interview(){
        return $this->hasMany('App\Models\InterviewSlot' , 'interviewee_id')->where('status' , 'A');
    }
    public function linterview(){
        return $this->whereRelation('interview' , function($query){
            return $query->where('status' , 'A');
        })->latest()->first();
    }
    public function languages(){
        return $this->hasMany('App\Models\VolunteerLanguage' , 'volunteer_id');
    }

    public function batch_traine(){
        return $this->hasOne('App\Models\Volunteer' , 'vlntr_id');
    }
  
   public function trainee(){
    return $this->hasMany('App\Models\TrainingBatchTraineesUpdate' , 'tbtu_trainee_id');

    }
    public function screening(){
        return $this->hasOne('App\Models\Screening' , 'client_id');
    
    }

    public function screening_volunteer(){
        return $this->hasone('App\Models\Volunteer' , 'vlntr_id');
    }

    public function ScreeningUpdateclient(){
        return $this->hasMany('App\Models\ScreeningCallUpdates' , 'client_id');
    } 

    public function volunteers(){
        return $this->hasOne('App\Models\Volunteer' , 'vlntr_id');

    }
        
      


}
